  /******************************************************************************
  * @file   PT32X005_adc.h
  * @author  ӦÿŶ
  * @version V1.1.0
  * @date    2020/1/27
  * @brief   This file contains all the functions prototypes for the ADC firmware library
  *          
  ******************************************************************************
  * @attention
  *
  *
  *****************************************************************************/

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef PT32X005_ADC_H
#define PT32X005_ADC_H

#ifdef __cplusplus
extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "PT32X005.h"


/** @addtogroup ADC
  * @{
  */


/* Exported types ------------------------------------------------------------*/

/** @brief  ADC Init structure definition **/
typedef struct
{
	u32 ADC_PSC_SEL;
	u32 ADC_MODE_SEL;               
	u32 ADC_ALIGN_SEL;		/*!< Specifies whether the ADC data alignment is left or right.
                                                 This parameter can be a value of @ref ADC_data_align */
	u32 ADC_BGS_SEL;       
	u32 ADC_TIMS_SEL;		/*!< Defines the external trigger used to start the analog
                                                 to digital conversion of regular channels. This parameter
                                                 can be a value of @ref ADC_external_trigger_sources_for_channels_conversion */
} ADC_InitTypeDef;


/* Exported constants --------------------------------------------------------*/
#define IS_ADC_ALL_PERIPH(PERIPH)	((PERIPH) == ADC)

/** @defgroup ADC_PSC_SEL **/
#define IS_ADC_PSC_SEL(SEL)		(((SEL) == ADC_CR_PSC_2)  ||\
								((SEL) == ADC_CR_PSC_4) ||\
								((SEL) == ADC_CR_PSC_8) ||\
								((SEL) == ADC_CR_PSC_16))
							
/** @defgroup ADC_MODE_SEL **/
#define IS_ADC_MODE_SEL(SEL)	(((SEL) == ADC_CR_MODE_Single)   ||\
								((SEL) == ADC_CR_MODE_Target)   ||\
								((SEL) == ADC_CR_MODE_Continuous))
										
/** @defgroup ADC_ALIGN_SEL **/
#define IS_ADC_ALIGN_SEL(SEL) 	(((SEL) == ADC_ALIGN_Right) || \
								((SEL) == ADC_ALIGN_Left))

/** @defgroup  ADC_BGS_SEL **/
#define IS_ADC_BGS_SEL(SEL)		(((SEL) == ADC_BGS_BG1v2) || \
								((SEL) == ADC_BGS_BG1v0))

/** @defgroup ADC_TIMS_SEL **/
#define IS_ADC_TIMS_SEL(SEL)	(((SEL) == ADC_CR_TIMS_TIM1_TRGO)||\
								((SEL) == ADC_CR_TIMS_TIM1_OC1)||\
								((SEL) == ADC_CR_TIMS_TIM1_OC2)||\
								((SEL) == ADC_CR_TIMS_TIM1_OC3)||\
								((SEL) == ADC_CR_TIMS_TIM1_OC4)||\
								((SEL) == ADC_CR_TIMS_TIM2_TRGO)||\
								((SEL) == ADC_CR_TIMS_TIM3_TRGO)||\
								((SEL) == ADC_CR_TIMS_None))

/** @defgroup ADC_channels **/
#define IS_ADC_CHS_SEL(SEL)		(((SEL) == ADC_CR_CHS_0) ||\
								((SEL) == ADC_CR_CHS_1) ||\
								((SEL) == ADC_CR_CHS_2) ||\
 								((SEL) == ADC_CR_CHS_3) ||\
								((SEL) == ADC_CR_CHS_4) ||\
								((SEL) == ADC_CR_CHS_5) ||\
								((SEL) == ADC_CR_CHS_6) ||\
								((SEL) == ADC_CR_CHS_7) ||\
								((SEL) == ADC_CR_CHS_8) ||\
								((SEL) == ADC_CR_CHS_9) ||\
								((SEL) == ADC_CR_CHS_10)) 
/** @defgroup IS_SPI_BR_VAL  **/
#define IS_ADC_SAM_VAL(Value) (((Value) > 2) && ((Value) < 256))

/** @defgroup ADC_flags_definition **/
#define ADC_FLAG_ADRDY		((u32)0x00000002) 	//ADC_READY
#define ADC_FLAG_EOC       	((u32)0x00000001)		//ADC End of Conversion 
#define IS_ADC_GET_FLAG(FLAG)	(((FLAG) == ADC_FLAG_ADRDY)   || \
								((FLAG) == ADC_FLAG_EOC))
#define IS_ADC_CLEAR_FLAG(FLAG) (((FLAG) != (u32)RESET) && (((FLAG) & 0xFFFFFFFC) == (u32)RESET))



/* Exported macro ------------------------------------------------------------*/
/* Exported functions ------------------------------------------------------- */
void ADC_DeInit(ADC_TypeDef* ADCx);
void ADC_Init(ADC_TypeDef* ADCx, ADC_InitTypeDef* ADC_InitStruct);
void ADC_StructInit(ADC_InitTypeDef* ADC_InitStruct);
void ADC_Cmd(ADC_TypeDef* ADCx, FunctionalState NewState);
void ADC_ChannelConfig(ADC_TypeDef* ADCx, u32 ADC_Channel);
void ADC_ConversionConfig(ADC_TypeDef* ADCx,FunctionalState NewState);
u16 ADC_GetConversionValue(ADC_TypeDef* ADCx);
void ADC_ITConfig(ADC_TypeDef* ADCx, u32 ADC_IT, FunctionalState NewState);
FlagStatus ADC_GetFlagStatus(ADC_TypeDef* ADCx, u32 ADC_FLAG);
void ADC_ClearFlag(ADC_TypeDef* ADCx, u32 ADC_FLAG);
void ADC_SetSampleTime(ADC_TypeDef* ADCx, u32 SAM_Time);
/**
  * @}
  */
  
#ifdef __cplusplus
}
#endif

#endif


